@@ -1,13 +1,18 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from trytond.model import ModelView, ModelSQL
+from trytond.pool import PoolMeta
 
 
-class User(ModelSQL, ModelView):
-    _name = 'res.user'
+__all__ = ['User']
+__metaclass__ = PoolMeta
 
-    def _get_preferences(self, user, context_only=False):
-        res = super(User, self)._get_preferences(user,
+
+class User:
+    __name__ = 'res.user'
+
+    @classmethod
+    def _get_preferences(cls, user, context_only=False):
+        res = super(User, cls)._get_preferences(user,
             context_only=context_only)
         if user.company:
             res['company_work_time'] = {
@@ -17,5 +22,3 @@ class User(ModelSQL, ModelView):
                 'd': user.company.hours_per_work_day,
             }
         return res
-
-User()
